Tools
=====

Simple functions complementing the core functionalities. Includes post processing and visualisations.

Post Processing
---------------
Processing of tomography results. Planned to be expanded. Currently only power computation implemented.

.. automodule :: tomotok.core.tools.postproc
    :members: compute_power
    :noindex:

Projection space
----------------
Transforms lines of sights into projections space parametrisation.

.. automodule:: tomotok.core.tools.projection
    :members: projection_space
    :undoc-members:
    :noindex:
